@@ -30,7 +30,7 @@ IpV6Delegate::~IpV6Delegate() {}
 QWidget * IpV6Delegate::createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &) const
 {
     QLineEdit *editor = new QLineEdit(parent);
-    editor->setValidator(new SimpleIpV6AddressValidator(editor));
+    editor->setValidator(new SimpleIpV6AddressValidator(SimpleIpV6AddressValidator::Base, editor));
 
     return editor;
 }
